# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta
from django.utils.translation import ugettext as _
from django.http import HttpResponseRedirect
from project.view import FuncView
from project.fal.command import get_message
from root.modules.form import BaseForm
from ..modules.protocol import Protocol
from django.core.exceptions import ValidationError
from django import forms
from project.forms.fields.extras.validators.fal import FALValidator
from root.modules.form.fields.radio import RadioField


def root(request):
    return HttpResponseRedirect('./ftp')


class FtpPortNumberValidator(FALValidator):
    validator = 'LocalPortNumber'
    options = {"service": "ftp_control", "exempt_null": "true"}


class FtpPortNumberField(forms.IntegerField):
    default_validators = [FtpPortNumberValidator()]
    default_error_messages = {}

    def __init__(self,
            attrs=None,
            required=None,
            widget=None,
            label=None,
            initial=None,
            help_text=None,
            *args, **kwargs):
        super(FtpPortNumberField, self).__init__(
                required=required,
                widget=widget or self.widget(attrs=attrs),
                label=label,
                initial=initial,
                help_text=help_text,
                *args, **kwargs)


class Form(BaseForm):

    def __init__(self, *args, **kwargs):
        super(Form, self).__init__(*args, **kwargs)

        self.fields["ftp"] = RadioField(
                label=_(u'FTP Share'),
                initial=0,
                required=True)
        self.fields["port"] = FtpPortNumberField(
                label=_(u'Port'),
                initial=21,
                required=True)
        self.fields["encode"] = RadioField(
                label=_(u'Encode'),
                choices=((0, _(u'Shift-JIS')), (1, _(u'UTF-8'))),
                initial=1,
                required=True)

    def clean(self):
        if self.cleaned_data.get("ftp") == "1":
            if "port" in self.cleaned_data.keys():
                if self.cleaned_data.get("port") in ["", None]:
                    raise ValidationError(_(u'"Port" is required.'))
        return self.cleaned_data

class View(FuncView):
    protocol = Protocol()
    views = ['apply']

    def view(self, request):
        return {
            self.KEY_TEMPLATE: self.TEMPLATE,
            self.KEY_TEMPLATE_DIC: {
                'form': Form(initial=self.protocol.get_ftp_config())}}

    def view_apply(self, request):
        with self.processing(constname="ERR_FTP_STATE_CHANGE") as p:
            form = Form(data=request.POST)
            rst = False
            p.break_if_state_change()

            if form.is_valid():
                if self.protocol.ftp_set(data=form.cleaned_data):
                    self.set_message(
                        get_message('MSG_FTP_CHANGE', is_log=True))
                    rst = True
                else:
                    self.set_message(
                        get_message('ERR_FTP_CHANGE', is_log=True))
                p.result(rst)

        return {
            self.KEY_TEMPLATE: self.TEMPLATE,
            self.KEY_TEMPLATE_DIC: {'form': form}}


ftp = View.as_view()
